Utils & Setting - 辅助函数和默认配置
====================================

..  note::

    这个模块只是把一些常用的辅助方法单独成文件而已，并不提供接口。
    纯用户（对实现不感兴趣的同学们）就不用看后面的啦。

..  automodule:: zhihu_oauth.utils
    :members:
    :undoc-members:
    :special-members:


..  automodule:: zhihu_oauth.setting
    :members:
    :undoc-members:
    :special-members:
